@@ -1,7 +1,6 @@
 import functools
 import logging
 import time
-from pubhelper.retry_wraps import retry_wraps as r
 
 
 def timethis(fn=None, *, logger=None):
@@ -24,7 +23,7 @@ def timethis(fn=None, *, logger=None):
     return callable(fn) and inner(fn) or inner
 
 
-def with_log(fn=None, *, logger=None, is_debug=False):
+def with_log(fn=None, *, logger=None):
     """打印日志"""
 
     def inner(f):
@@ -32,7 +31,7 @@ def with_log(fn=None, *, logger=None, is_debug=False):
         def _inner(*args, **kwargs):
             logger.debug(
                 f'func({f.__name__}) running(args={args}, kwargs={kwargs})')
-            result = r(f, is_debug=is_debug)(*args, **kwargs)
+            result = f(*args, **kwargs)
             if isinstance(result, Exception):
                 logger.error(f'func({f.__name__}) error: {result}')
             else:
@@ -42,7 +41,7 @@ def with_log(fn=None, *, logger=None, is_debug=False):
         return _inner
 
     if not logger:
-        logger = logging.getLogger('__debug__')
+        logger = logging.getLogger('__with_log__')
     logger.setLevel(logging.DEBUG)
     return callable(fn) and inner(fn) or inner
 
